@@ -32,9 +32,9 @@ class TransferFileJob : public KJob
     Q_OBJECT
 
 public:
-    explicit TransferFileJob(BluezQt::ObexTransferPtr transfer, KioFtp *parent = 0);
+    explicit TransferFileJob(BluezQt::ObexTransferPtr transfer, KioFtp *parent = nullptr);
 
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 private Q_SLOTS:
     void doStart();
